OptimizationControlMechanism
============================

.. automodule:: psyneulink.core.components.mechanisms.modulatory.control.optimizationcontrolmechanism
   :members:
   :private-members:
   :exclude-members: Linear, random, Parameters
